<?php
//
// Copyright 2015, Julian Catchen <jcatchen@illinois.edu>
//
// This file is part of Chromonomer.
//
// Chromonomer is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Chromonomer is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Chromonomer.  If not, see <http://www.gnu.org/licenses/>.
//

function write_header($page_title) {
  global $root_path;

    echo <<< EOQ
<!DOCTYPE html>
<html>
    <head>
	<meta charset="utf-8">
    <title>$page_title</title>
    <link rel="stylesheet" type="text/css" href="$root_path/lgs.css" />
    <script type="text/javascript" src="$root_path/lgs.js"></script>
    </head>

    <body>

EOQ;
}

function write_extended_header($page_title) {
  global $root_path;

    echo <<< EOQ
<!DOCTYPE html>
<html>
    <head>
	<meta charset="utf-8">
    <title>$page_title</title>
    <link rel="stylesheet" type="text/css" href="$root_path/lgs.css" />
	<link rel="stylesheet" type="text/css" href="https://maxcdn.bootstrapcdn.com/font-awesome/4.4.0/css/font-awesome.min.css">
    <script type="text/javascript" src="$root_path/lgs.js"></script>
	<script type="text/javascript" src="https://cdnjs.cloudflare.com/ajax/libs/d3/3.5.6/d3.min.js"></script>
	<script type="text/javascript" src="https://ajax.googleapis.com/ajax/libs/jquery/2.1.3/jquery.min.js"></script>
    </head>

    <body>

EOQ;
}

function write_compact_header($page_title) {
  global $root_path;

    echo <<< EOQ
<!DOCTYPE html>
<html>
    <head>
	<meta charset="utf-8">
    <title>$page_title</title>
    <link rel="stylesheet" type="text/css" href="$root_path/lgs.css" />
    <script type="text/javascript" src="$root_path/lgs.js"></script>
    </head>

    <body>

EOQ;
}

function write_footer() {

    echo <<< EOQ
<div class="footer">
  <div style="float: left;">
      Last Updated: 
EOQ;

    include("last_modified.php");

    echo <<< EOQ
  </div>
</div>

</body>
</html>

EOQ;
}

function write_compact_footer() {

    echo <<< EOQ

</body>
</html>

EOQ;
}

function write_assembly($lg, $version) {
    global $root_path, $file_path;

    print 
      "<table class=\"assembly\">\n" .
      "<tr>\n" .
      "  <th>Master BP</th>\n" .
      "  <th>Scaffold</th>\n" .
      "  <th>Orientation</th>\n" .
      "  <th>Start BP</th>\n" .
      "  <th>End BP</th>\n" .
      "  <th>Former Scaffold</th>\n" .
      "</tr>";

    $fh = fopen("$file_path/". $version . "/" . $lg . "_scaffold.tsv", "r");

    if ($fh) {
      while (($buffer = fgets($fh, 256)) !== false) {
  	  $parts = explode("\t", $buffer);

	  $ori = $parts[2] == "+" ? 
	    "<span class=\"for\">$parts[2]</span>" : 
	    "<span class=\"rev\">$parts[2]</span>";

	  $scaf = $parts[1];

	  $path = "$file_path/" . $version . "/" . $scaf . ".log";
	  $link = "$root_path/view_log.php?v=$version&log=" . $parts[1];
	  if (file_exists($path)) {
	    $scaf = "<a target=\"blank\" href=\"$link\">$parts[1]</a>";
	  }

	  if (count($parts) >= 6) {
	    $old_scaf = substr($parts[5], 1, -2);
	    $path = "$file_path/" . $version . "/" . $old_scaf . ".log";
	    $link = "$root_path/view_log.php?v=$version&log=" . $old_scaf;
	    if (file_exists($path)) {
	      $old_scaf = "<a target=\"blank\" href=\"$link\">$old_scaf</a>";
	    }
	  } else {
	    $old_scaf = "&nbsp;";
	  }

	  print 
	    "<tr>\n" .
	    "  <td class=\"bp\">$parts[0]</td>\n" .
	    "  <td class=\"scaf\">$scaf</td>\n" .
	    "  <td class=\"ori\">$ori</td>\n" .
	    "  <td class=\"bp\">$parts[3]</td>\n" .
	    "  <td class=\"bp\">$parts[4]</td>\n" .
	    "  <td class=\"scaf\">$old_scaf</td>\n" .
	    "</tr>\n";
      }
      if (!feof($fh)) {
        echo "Error: unexpected fgets() fail\n";
      }
    }

    fclose($fh);

    print "</table>\n";
}

function find_chrr_runs($file_path)
{
    $files = scandir($file_path);
    $versions = array();

    foreach ($files as $file) {
        if ($file[0] == '.')
            continue;

        if (is_dir("$file_path/$file")) {
            $path = $file_path  . "/" . $file . "/chromonomer_summary.log";
            if (file_exists($path))
                array_push($versions, $file);
        }
    }

    return $versions;
}

function find_chrr_lgs($file_path, $ver)
{
    $files = scandir($file_path . "/" . $ver);
    $lgs = array();

    foreach ($files as $file) {
        if ($file[0] == '.')
            continue;

        if (substr_compare($file, "_after.json", -11) == 0)
            array_push($lgs, substr($file, 0, (strlen($file) - 11)));
    }

    return $lgs;
}

?>
