// -*-mode:c++; c-style:k&r; c-basic-offset:4;-*-
//
// Copyright 2015-2019, Julian Catchen <jcatchen@illinois.edu>
//
// This file is part of Chromonomer.
//
// Chromonomer is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Chromonomer is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Chromonomer.  If not, see <http://www.gnu.org/licenses/>.
//

#ifndef __CONSTANTS_H__
#define __CONSTANTS_H__

#include <cstddef>
#include <utility>
using std::pair;
using std::make_pair;
#include <vector>
using std::vector;
#include <string>
using std::string;
#include <iostream>
#include <ostream>
#include <fstream>
using std::ifstream;
using std::ofstream;
using std::ostream;
using std::istream;
using std::cin;
using std::cout;
using std::cerr;
#include <tuple>
using std::tuple;
using std::tie;
#include <algorithm>
#include <cassert>
#include <cstring>
#include <stdexcept>

#include <zlib.h>   // Support for gzipped output files.

//
// Pull in the configuration variables from the configure script
//
#if HAVE_CONFIG_H
#include "config.h"
#endif

typedef unsigned char uchar;
typedef unsigned int  uint;
//
// Maximum line length for parsing input files.
//
const int max_len = 1024;

//
// Maximum length of identifiers, such as sequence IDs and chromosome names.
//
const int id_len = 255;

//
// FASTA line length.
//
const int fasta_line_len = 80;

//
// Size to use for internal buffer size for gzipped files being read with libz.
//
const int libz_buffer_size = 1048576;

enum comp_type   {gap, contig, virtual_gap};
enum ann_type    {seg_beg, seg_end};
enum ori_type    {ori_forward, ori_reverse, ori_unknown};
enum dynprg_type {path_left, path_diagup};

#endif
